from random import randint


def roll(roll):
    rolling = []
    numberOfRolls = int(roll.split('d')[0])
    diceCount = int(roll.split('d')[1])
    try:
        for x in range(numberOfRolls):
            print(f"Rolling die {x+1}...")
            result = randint(1, diceCount)
            print(f"Result: {result}")
            rolling.append(result)
    except Exception as err:
        print(f'I got bungled @_@ \n Error: {err}')

    return rolling, sum(rolling)


def printResult(listOfRolls, sumOfRolls):
    print(f'You rolled {listOfRolls} which has a total'
          f' of {sumOfRolls}')


def rolldice(x):
    rollList, rollTotal = roll(x)
    printResult(rollList, rollTotal)


from setuptools import find_packages, setup

setup(
    name='Any Dice Simulator',
    packages=find_packages(include=['anyDiceSimulator']),
    version='0.0.1',
    description='Python library to roll dice!',
    author='Saksham Gupta',
    license='MIT',
    install_requires=[],
    setup_requires=['pytest-runner'],
    tests_require=['pytest'],
    test_suite='tests',
)


import random


class Die:
    def __init__(self, sides=6, numOnSides=[1, 2, 3, 4, 5, 6]):
        self.sides = sides
        self.numOnSides = numOnSides

    def dieProperties(self):
        print("==========================================")
        print("Die properties ->")
        print(f"Number of sides: {self.sides}")
        print(f"Numbering on sides: {self.numOnSides}")
        print("Biased: False")
        print("Side weights: None")
        print("==========================================")

    def rollDie(self, n):
        print(f"Number of rolls: {n}")
        result = random.choices(self.numOnSides, k=n)
        return result, sum(result)


class regularDie(Die):
    def __init__(self, sides=6, numOnSides=[1, 2, 3, 4, 5, 6]):
        self.sides = sides
        self.numOnSides = list(range(1, self.sides + 1))

    def dieProperties(self):
        print("==========================================")
        print("Die properties ->")
        print(f"Number of sides: {self.sides}")
        print(f"Numbering on sides: {self.numOnSides}")
        print("Biased: False")
        print("Side weights: None")
        print("==========================================")

    def rollDie(self, n):
        print(f"Number of rolls: {n}")
        result = random.choices(self.numOnSides, k=n)
        return result, sum(result)


class biasedDie(Die):
    def __init__(self, sides=6, numOnSides=[1, 2, 3, 4, 5, 6], biasWeights=[1, 1, 1, 1, 1, 10]):
        self.sides = sides
        self.numOnSides = numOnSides
        self.biasWeights = biasWeights

    def dieProperties(self):
        print("==========================================")
        print("Die properties ->")
        print(f"Number of sides: {self.sides}")
        print(f"Numbering on sides: {self.numOnSides}")
        print("Biased: True")
        print(f"Side weights: {self.biasWeights}")
        print("==========================================")

    def rollDie(self, n):
        print(f"Number of rolls: {n}")
        result = random.choices(self.numOnSides, k=n, weights=self.biasWeights)
        return result, sum(result)
